---
name: Feature Suggestion 💡
about: Suggest a new idea for the project.
labels: "enhancement"
---

<!--
  To make it easier for us to help you, please include as much useful information as possible.

  Useful Links:
  - Wiki: https://docs.garak.ai/garak

  Before opening a new issue, please search existing issues https://github.com/NVIDIA/garak/issues
-->

## Summary

Brief explanation of the feature.

### Basic example

If the proposal involves a new or changed API, include a basic code example. Omit this section if it's not applicable.

### Motivation

Why are we doing this? What use cases does it support? What is the expected outcome?
